package cn.com.infosec.mobile.android.xlog.internal;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.os.Bundle;
import android.os.Build.VERSION;
import android.support.annotation.Keep;
import cn.com.infosec.mobile.android.xlog.formatter.message.object.BundleFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.object.IntentFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.object.ObjectFormatter;
import cn.com.infosec.mobile.android.xlog.printer.AndroidPrinter;
import cn.com.infosec.mobile.android.xlog.printer.ConsolePrinter;
import cn.com.infosec.mobile.android.xlog.printer.Printer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

@Keep
public class Platform {
   private static final Platform PLATFORM = findPlatform();

   public static Platform get() {
      return PLATFORM;
   }

   private static Platform findPlatform() {
      boolean var10001;
      try {
         Class.forName("android.os.Build");
      } catch (ClassNotFoundException var3) {
         var10001 = false;
         return new Platform();
      }

      int var10000;
      try {
         var10000 = VERSION.SDK_INT;
      } catch (ClassNotFoundException var2) {
         var10001 = false;
         return new Platform();
      }

      if (var10000 != 0) {
         try {
            return new Android();
         } catch (ClassNotFoundException var1) {
            var10001 = false;
         }
      }

      return new Platform();
   }

   @SuppressLint({"NewApi"})
   String lineSeparator() {
      return System.lineSeparator();
   }

   Printer defaultPrinter() {
      return new ConsolePrinter();
   }

   Map<Class<?>, ObjectFormatter<?>> builtinObjectFormatters() {
      return Collections.emptyMap();
   }

   public void warn(String msg) {
      System.out.println(msg);
   }

   public void error(String msg) {
      System.out.println(msg);
   }

   static class Android extends Platform {
      private static final Map<Class<?>, ObjectFormatter<?>> BUILTIN_OBJECT_FORMATTERS;

      static {
         HashMap var10000 = new HashMap();
         BundleFormatter var0;
         var0 = new BundleFormatter.<init>();
         var10000.put(Bundle.class, var0);
         IntentFormatter var1;
         var1 = new IntentFormatter.<init>();
         var10000.put(Intent.class, var1);
         BUILTIN_OBJECT_FORMATTERS = Collections.unmodifiableMap(var10000);
      }

      String lineSeparator() {
         return VERSION.SDK_INT < 19 ? "\n" : System.lineSeparator();
      }

      Printer defaultPrinter() {
         return new AndroidPrinter();
      }

      Map<Class<?>, ObjectFormatter<?>> builtinObjectFormatters() {
         return BUILTIN_OBJECT_FORMATTERS;
      }

      public void warn(String msg) {
      }

      public void error(String msg) {
      }
   }
}
